@@ -309,6 +309,16 @@
 #  undef MONGOC_ENABLE_COMPRESSION_ZLIB
 #endif
 
+/*
+ * Set if we have zstd compression support
+ *
+ */
+#define MONGOC_ENABLE_COMPRESSION_ZSTD 1
+
+#if MONGOC_ENABLE_COMPRESSION_ZSTD != 1
+#  undef MONGOC_ENABLE_COMPRESSION_ZSTD
+#endif
+
 /*
  * Set if performance counters are available and not disabled.
  *
